Crate pnets_shrunk

Provides an API to reduce Petri nets

Modifications

This module exposes all modifications that can be done on the network

Reducers

This module exposes a complete API to create custom reduction and use existing ones.

Modules