pnets_shrunk

Module reducers

All reducers supported by this crate

This module contains an API to create reductions and some already implemented reductions.

Modules

  • All reductions appliable to standard network

Structs

  • Apply the first reduction and then the second reduction
  • Identity reducer does nothing on the network
  • Executes a reduction rule in a loop as long as there have been changes in the network
  • Execute a reduction, then on each transition and place modified we execute the actions PostPlace and PostTransition on each of the modifications

Traits

  • All reduction which implement this trait should keep the count of markings (the set of equations should has exactly the same number of solutions than the original network)
  • Try to apply a reduction rule on a specific place
  • Apply a reduction rule to the network
  • Try to apply a reduction rule on a specific place

Type Aliases