All reductions appliable to standard network
Structs
- Removes identity places, which has a constant value
- Removes identity transitions, which doesn’t have an effect on the network
- Removes redundant places which have the same producers and consumers
- Removes redundant transitions which have the same producers and consumers
- Reduction for Election2020 net
- Removes the pattern “pl -> tr” from the network (pl and tr don’t has other connection)
- RL Reducer
- Remove simple chains from the network and replace them by a unique place
- Remove simple loopd from the network and replace them by a unique place
- Replaces a place that has an initial marking equal to all the weights of the related arcs
Type Aliases
- Alias to Smart reducer which try to remove parallel places and parallel transitions after each modifications