pnets_shrunk::reducers

Struct ChainReducer

pub struct ChainReducer<Net, First, Second>(/* private fields */)
where
    First: Reduce<Net>,
    Second: Reduce<Net>;
Apply the first reduction and then the second reduction

This struct also implement PlaceReduce and TransitionReduce to allows chaining reductions on a specific place or transition