pub struct IdentityReducer {}Expand description
Identity reducer does nothing on the network
This reduction exists only to be able to easily test reduction chains or replace required parameters in others.