pnets_shrunk::reducers

Struct LoopReducer

pub struct LoopReducer<Net, Red>(/* private fields */)
where
    Red: Reduce<Net>;
Executes a reduction rule in a loop as long as there have been changes in the network