pnets_shrunk::reducers

Trait PlaceReduce

pub trait PlaceReduce<Net>: Reduce<Net> {
    // Required method
    fn place_reduce(
        net: &mut Net,
        pl: PlaceId,
        modifications: &mut Vec<Modification>,
    );
}
Try to apply a reduction rule on a specific place

Required Methods

fn place_reduce( net: &mut Net, pl: PlaceId, modifications: &mut Vec<Modification>, )

Try to apply a reduction rule on a specific place

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors