pnets_shrunk::reducers

Trait Reduce

pub trait Reduce<Net> {
    // Required method
    fn reduce(net: &mut Net, modifications: &mut Vec<Modification>);
}
Apply a reduction rule to the network

Required Methods

fn reduce(net: &mut Net, modifications: &mut Vec<Modification>)

Compute a reduction rule on the network

In general, this method should iterate over each place or transition and try to apply the reduction to each place or transition.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Reduce<Net> for IdentityPlaceReducer

Source

impl Reduce<Net> for IdentityTransitionReducer

Source

impl Reduce<Net> for ParallelPlaceReducer

Source

impl Reduce<Net> for ParallelTransitionReducer

Source

impl Reduce<Net> for PseudoStart

Source

impl Reduce<Net> for R7Reducer

Source

impl Reduce<Net> for RLReducer

Source

impl Reduce<Net> for SimpleChainReducer

Source

impl Reduce<Net> for SimpleLoopAgglomeration

Source

impl Reduce<Net> for WeightSimplification

Source

impl<Net> Reduce<Net> for IdentityReducer

Source

impl<Net, First, Second> Reduce<Net> for ChainReducer<Net, First, Second>
where First: Reduce<Net>, Second: Reduce<Net>,

Source

impl<Net, Red> Reduce<Net> for LoopReducer<Net, Red>
where Red: Reduce<Net>,

Source

impl<Net, Red, PostPlace, PostTransition> Reduce<Net> for SmartReducer<Net, Red, PostPlace, PostTransition>
where Red: Reduce<Net>, PostPlace: PlaceReduce<Net>, PostTransition: TransitionReduce<Net>,