pub trait PlaceReduce<Net>: Reduce<Net> {
// Required method
fn place_reduce(
net: &mut Net,
pl: PlaceId,
modifications: &mut Vec<Modification>,
);
}Expand description
Try to apply a reduction rule on a specific place
Required Methods
Sourcefn place_reduce(
net: &mut Net,
pl: PlaceId,
modifications: &mut Vec<Modification>,
)
fn place_reduce( net: &mut Net, pl: PlaceId, modifications: &mut Vec<Modification>, )
Try to apply a reduction rule on a specific place
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.