pub trait Reduce<Net> {
// Required method
fn reduce(net: &mut Net, modifications: &mut Vec<Modification>);
}Expand description
Apply a reduction rule to the network
Required Methods
Sourcefn reduce(net: &mut Net, modifications: &mut Vec<Modification>)
fn reduce(net: &mut Net, modifications: &mut Vec<Modification>)
Compute a reduction rule on the network
In general, this method should iterate over each place or transition and try to apply the reduction to each place or transition.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.